bibentry(bibtype = "Book",
         key = "Press+Teukolsky+Vetterling:1992",
         author = c(person(given = c("William", "H."),
                           family = "Press"),
                    person(given = c("Saul", "A."),
                           family = "Teukolsky"),
                    person(given = c("William", "T."),
                           family = "Vetterling"),
                    person(given = c("Brian", "P."),
                           family = "Flannery")),
         title = "Numerical Recipes in {C}: The Art of Scientific Computing",
         publisher = "Cambridge University Press",
         year = "1992",
         edition = "Second",
         isbn = "978-0521431088")
